Crate minigrep_demo

My Crate

my_crate is a collection of utilities to make performing certain calculations more convenient.

Structs

Config
struct Config Add by lryong

Functions

run
run function for Search This is the app entrance.
search
Search feature exmaple TODO